@@ -1,27 +1,14 @@
 /*
-      Copyright 2014 Dominik Haumann <dhaumann@kde.org>
-      Copyright 2017 Friedrich W. H. Kossebau <kossebau@kde.org>
+    SPDX-FileCopyrightText: 2014 Dominik Haumann <dhaumann@kde.org>
+    SPDX-FileCopyrightText: 2017 Friedrich W. H. Kossebau <kossebau@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kmessagewidgetautotest.h"
 
-#include <QTest>
 #include <QSignalSpy>
+#include <QTest>
 #include <kmessagewidget.h>
 
 QTEST_MAIN(KMessageWidgetTest)
@@ -30,6 +17,7 @@ QTEST_MAIN(KMessageWidgetTest)
 // let's have 7 updates for now, should be save
 const int overlappingWaitingTime = 280;
 
+// clang-format off
 #define CHECK_FULLY_VISIBLE \
     QVERIFY(w.isVisible()); \
     QCOMPARE(w.height(), w.sizeHint().height()); \
@@ -37,7 +25,7 @@ const int overlappingWaitingTime = 280;
 #define CHECK_FULLY_NOT_VISIBLE \
     QCOMPARE(w.height(), 0); \
     QVERIFY(!w.isVisible());
-
+// clang-format on
 
 void KMessageWidgetTest::testAnimationSignals()
 {
@@ -94,14 +82,14 @@ void KMessageWidgetTest::testHideOnInvisible()
 
     QTRY_VERIFY(!w.isHideAnimationRunning());
     QCOMPARE(hideSignalsSpy.count(), 1);
-    QVERIFY(! w.isVisible()); // Not CHECK_FULLY_NOT_VISIBLE because since it was never shown height is not what it would be otherwise
+    QVERIFY(!w.isVisible()); // Not CHECK_FULLY_NOT_VISIBLE because since it was never shown height is not what it would be otherwise
 }
 
 void KMessageWidgetTest::testOverlappingShowAndHide_data()
 {
     QTest::addColumn<bool>("delay");
     QTest::newRow("instant") << false;
-    QTest::newRow("delay")   << true;
+    QTest::newRow("delay") << true;
 }
 
 void KMessageWidgetTest::testOverlappingShowAndHide()
@@ -121,7 +109,7 @@ void KMessageWidgetTest::testOverlappingShowAndHide()
     }
     w.animatedHide();
 
-    QVERIFY(! w.isShowAnimationRunning());
+    QVERIFY(!w.isShowAnimationRunning());
     QCOMPARE(showSignalsSpy.count(), 1);
 
     QTRY_VERIFY(!w.isHideAnimationRunning());
@@ -133,7 +121,7 @@ void KMessageWidgetTest::testOverlappingHideAndShow_data()
 {
     QTest::addColumn<bool>("delay");
     QTest::newRow("instant") << false;
-    QTest::newRow("delay")   << true;
+    QTest::newRow("delay") << true;
 }
 
 void KMessageWidgetTest::testOverlappingHideAndShow()
@@ -153,7 +141,7 @@ void KMessageWidgetTest::testOverlappingHideAndShow()
     }
     w.animatedShow();
 
-    QVERIFY(! w.isHideAnimationRunning());
+    QVERIFY(!w.isHideAnimationRunning());
     QCOMPARE(hideSignalsSpy.count(), 1);
 
     QTRY_VERIFY(!w.isShowAnimationRunning());
@@ -165,7 +153,7 @@ void KMessageWidgetTest::testOverlappingDoubleShow_data()
 {
     QTest::addColumn<bool>("delay");
     QTest::newRow("instant") << false;
-    QTest::newRow("delay")   << true;
+    QTest::newRow("delay") << true;
 }
 
 void KMessageWidgetTest::testOverlappingDoubleShow()
@@ -191,7 +179,7 @@ void KMessageWidgetTest::testOverlappingDoubleHide_data()
 {
     QTest::addColumn<bool>("delay");
     QTest::newRow("instant") << false;
-    QTest::newRow("delay")   << true;
+    QTest::newRow("delay") << true;
 }
 
 void KMessageWidgetTest::testOverlappingDoubleHide()
@@ -227,7 +215,7 @@ void KMessageWidgetTest::testHideWithNotYetShownParent()
     parent.show();
 
     QCOMPARE(hideSignalsSpy.count(), 1);
-    QVERIFY(! w.isVisible()); // Not CHECK_FULLY_NOT_VISIBLE because since it was never shown height is not what it would be otherwise
+    QVERIFY(!w.isVisible()); // Not CHECK_FULLY_NOT_VISIBLE because since it was never shown height is not what it would be otherwise
 }
 
 void KMessageWidgetTest::testNonAnimatedShowAfterAnimatedHide()
@@ -248,3 +236,12 @@ void KMessageWidgetTest::testNonAnimatedShowAfterAnimatedHide()
     w.show();
     CHECK_FULLY_VISIBLE
 }
+
+void KMessageWidgetTest::testResizeFlickerOnAnimatedShow()
+{
+    KMessageWidget w(QStringLiteral("Hello world"));
+
+    w.animatedShow();
+
+    QCOMPARE(w.height(), 0);
+}
