@@ -12,15 +12,15 @@
 #include <QApplication>
 #include <QEvent>
 #include <QGridLayout>
+#include <QGuiApplication>
 #include <QHBoxLayout>
 #include <QLabel>
 #include <QPainter>
 #include <QShowEvent>
+#include <QStyle>
 #include <QStyleOption>
 #include <QTimeLine>
 #include <QToolButton>
-#include <QStyle>
-#include <QGuiApplication>
 //---------------------------------------------------------------------
 // KMessageWidgetPrivate
 //---------------------------------------------------------------------
@@ -38,8 +38,7 @@ public:
     QToolButton *closeButton = nullptr;
     QTimeLine *timeLine = nullptr;
     QIcon icon;
-    bool ignoreShowEventDoingAnimatedShow = false;
-
+    bool ignoreShowAndResizeEventDoingAnimatedShow = false;
     KMessageWidget::MessageType messageType;
     bool wordWrap;
     QList<QToolButton *> buttons;
@@ -57,8 +56,12 @@ void KMessageWidgetPrivate::init(KMessageWidget *q_ptr)
     q = q_ptr;
     // Note: when changing the value 500, also update KMessageWidgetTest
     timeLine = new QTimeLine(500, q);
-    QObject::connect(timeLine, SIGNAL(valueChanged(qreal)), q, SLOT(slotTimeLineChanged(qreal)));
-    QObject::connect(timeLine, SIGNAL(finished()), q, SLOT(slotTimeLineFinished()));
+    QObject::connect(timeLine, &QTimeLine::valueChanged, q, [this](qreal value) {
+        slotTimeLineChanged(value);
+    });
+    QObject::connect(timeLine, &QTimeLine::finished, q, [this]() {
+        slotTimeLineFinished();
+    });
 
     wordWrap = false;
 
@@ -87,7 +90,9 @@ void KMessageWidgetPrivate::init(KMessageWidget *q_ptr)
 
     q->setMessageType(KMessageWidget::Information);
 
-    q->connect(qApp, &QApplication::paletteChanged, q, [this] {KMessageWidgetPrivate::setPalette();});
+    q->connect(qApp, &QApplication::paletteChanged, q, [this] {
+        KMessageWidgetPrivate::setPalette();
+    });
 }
 
 void KMessageWidgetPrivate::createLayout()
@@ -103,6 +108,8 @@ void KMessageWidgetPrivate::createLayout()
         QToolButton *button = new QToolButton(q);
         button->setDefaultAction(action);
         button->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
+        auto previous = buttons.isEmpty() ? static_cast<QWidget *>(textLabel) : buttons.back();
+        QWidget::setTabOrder(previous, button);
         buttons.append(button);
     }
 
@@ -123,7 +130,7 @@ void KMessageWidgetPrivate::createLayout()
             // Use an additional layout in row 1 for the buttons.
             QHBoxLayout *buttonLayout = new QHBoxLayout;
             buttonLayout->addStretch();
-            for (QToolButton *button : qAsConst(buttons)) {
+            for (QToolButton *button : std::as_const(buttons)) {
                 // For some reason, calling show() is necessary if wordwrap is true,
                 // otherwise the buttons do not show up. It is not needed if
                 // wordwrap is false.
@@ -135,13 +142,13 @@ void KMessageWidgetPrivate::createLayout()
         }
     } else {
         QHBoxLayout *layout = new QHBoxLayout(q);
-        layout->addWidget(iconLabel);
+        layout->addWidget(iconLabel, 0, Qt::AlignTop);
         layout->addWidget(textLabel);
 
-        for (QToolButton *button : qAsConst(buttons)) {
-            layout->addWidget(button);
+        for (QToolButton *button : std::as_const(buttons)) {
+            layout->addWidget(button, 0, Qt::AlignTop);
         }
-        layout->addWidget(closeButton);
+        layout->addWidget(closeButton, 0, Qt::AlignTop);
     };
     // Add bordersize to the margin so it starts from the inner border and doesn't look too cramped
     q->layout()->setContentsMargins(q->layout()->contentsMargins() + borderSize);
@@ -160,7 +167,7 @@ void KMessageWidgetPrivate::setPalette()
     // The following RGB color values come from the "default" scheme in kcolorscheme.cpp
     switch (messageType) {
     case KMessageWidget::Positive:
-        bgBaseColor.setRgb(39, 174,  96); // Window: ForegroundPositive
+        bgBaseColor.setRgb(39, 174, 96); // Window: ForegroundPositive
         break;
     case KMessageWidget::Information:
         bgBaseColor.setRgb(61, 174, 233); // Window: ForegroundActive
@@ -204,11 +211,11 @@ void KMessageWidgetPrivate::slotTimeLineFinished()
         q->resize(q->width(), bestContentHeight());
 
         // notify about finished animation
-        emit q->showAnimationFinished();
+        Q_EMIT q->showAnimationFinished();
     } else {
         // hide and notify about finished animation
         q->hide();
-        emit q->hideAnimationFinished();
+        Q_EMIT q->hideAnimationFinished();
     }
 }
 
@@ -239,10 +246,7 @@ KMessageWidget::KMessageWidget(const QString &text, QWidget *parent)
     setText(text);
 }
 
-KMessageWidget::~KMessageWidget()
-{
-    delete d;
-}
+KMessageWidget::~KMessageWidget() = default;
 
 QString KMessageWidget::text() const
 {
@@ -282,7 +286,7 @@ bool KMessageWidget::event(QEvent *event)
 {
     if (event->type() == QEvent::Polish && !layout()) {
         d->createLayout();
-    } else if (event->type() == QEvent::Show && !d->ignoreShowEventDoingAnimatedShow) {
+    } else if (event->type() == QEvent::Show && !d->ignoreShowAndResizeEventDoingAnimatedShow) {
         setFixedHeight(d->bestContentHeight());
     } else if (event->type() == QEvent::ParentChange) {
         d->setPalette();
@@ -293,7 +297,7 @@ bool KMessageWidget::event(QEvent *event)
 void KMessageWidget::resizeEvent(QResizeEvent *event)
 {
     QFrame::resizeEvent(event);
-    if (d->timeLine->state() == QTimeLine::NotRunning) {
+    if (d->timeLine->state() == QTimeLine::NotRunning && d->ignoreShowAndResizeEventDoingAnimatedShow) {
         setFixedHeight(d->bestContentHeight());
     }
 }
@@ -369,29 +373,37 @@ void KMessageWidget::removeAction(QAction *action)
     d->updateLayout();
 }
 
+void KMessageWidget::clearActions()
+{
+    const auto ourActions = actions();
+    for (auto *action : ourActions) {
+        removeAction(action);
+    }
+    d->updateLayout();
+}
+
 void KMessageWidget::animatedShow()
 {
     // Test before styleHint, as there might have been a style change while animation was running
     if (isHideAnimationRunning()) {
         d->timeLine->stop();
-        emit hideAnimationFinished();
+        Q_EMIT hideAnimationFinished();
     }
 
-    if (!style()->styleHint(QStyle::SH_Widget_Animate, nullptr, this)
-     || (parentWidget() && !parentWidget()->isVisible())) {
+    if (!style()->styleHint(QStyle::SH_Widget_Animate, nullptr, this) || (parentWidget() && !parentWidget()->isVisible())) {
         show();
-        emit showAnimationFinished();
+        Q_EMIT showAnimationFinished();
         return;
     }
 
     if (isVisible() && (d->timeLine->state() == QTimeLine::NotRunning) && (height() == d->bestContentHeight())) {
-        emit showAnimationFinished();
+        Q_EMIT showAnimationFinished();
         return;
     }
 
-    d->ignoreShowEventDoingAnimatedShow = true;
+    d->ignoreShowAndResizeEventDoingAnimatedShow = true;
     show();
-    d->ignoreShowEventDoingAnimatedShow = false;
+    d->ignoreShowAndResizeEventDoingAnimatedShow = false;
     setFixedHeight(0);
 
     d->timeLine->setDirection(QTimeLine::Forward);
@@ -407,19 +419,19 @@ void KMessageWidget::animatedHide()
     // And before styleHint, as there might have been a style change while animation was running
     if (isShowAnimationRunning()) {
         d->timeLine->stop();
-        emit showAnimationFinished();
+        Q_EMIT showAnimationFinished();
     }
 
     if (!style()->styleHint(QStyle::SH_Widget_Animate, nullptr, this)) {
         hide();
-        emit hideAnimationFinished();
+        Q_EMIT hideAnimationFinished();
         return;
     }
 
     if (!isVisible()) {
         // explicitly hide it, so it stays hidden in case it is only not visible due to the parents
         hide();
-        emit hideAnimationFinished();
+        Q_EMIT hideAnimationFinished();
         return;
     }
 
@@ -431,14 +443,12 @@ void KMessageWidget::animatedHide()
 
 bool KMessageWidget::isHideAnimationRunning() const
 {
-    return (d->timeLine->direction() == QTimeLine::Backward)
-        && (d->timeLine->state() == QTimeLine::Running);
+    return (d->timeLine->direction() == QTimeLine::Backward) && (d->timeLine->state() == QTimeLine::Running);
 }
 
 bool KMessageWidget::isShowAnimationRunning() const
 {
-    return (d->timeLine->direction() == QTimeLine::Forward)
-        && (d->timeLine->state() == QTimeLine::Running);
+    return (d->timeLine->direction() == QTimeLine::Forward) && (d->timeLine->state() == QTimeLine::Running);
 }
 
 QIcon KMessageWidget::icon() const
@@ -459,4 +469,3 @@ void KMessageWidget::setIcon(const QIcon &icon)
 }
 
 #include "moc_kmessagewidget.cpp"
-
