@@ -7,19 +7,16 @@
 #ifndef _KMultitabbar_h_
 #define _KMultitabbar_h_
 
-#include <QString>
 #include <QPushButton>
+#include <QString>
+#include <memory>
 
 #include <kwidgetsaddons_export.h>
 
 class QPixmap;
-class QPainter;
 class QMenu;
 class QStyleOptionToolButton;
 
-class KMultiTabBarPrivate;
-class KMultiTabBarTabPrivate;
-class KMultiTabBarButtonPrivate;
 class KMultiTabBarInternal;
 
 /**
@@ -36,7 +33,7 @@ class KMultiTabBarInternal;
  *
  * @author Joseph Wenninger
  */
-class KWIDGETSADDONS_EXPORT KMultiTabBar: public QWidget
+class KWIDGETSADDONS_EXPORT KMultiTabBar : public QWidget
 {
     Q_OBJECT
     Q_PROPERTY(KMultiTabBarPosition position READ position WRITE setPosition)
@@ -49,9 +46,9 @@ public:
      * The list of available styles for KMultiTabBar
      */
     enum KMultiTabBarStyle {
-        VSNET = 0,     ///< Visual Studio .Net like, always shows icon, only show the text of active tabs
+        VSNET = 0, ///< Visual Studio .Net like, always shows icon, only show the text of active tabs
         KDEV3ICON = 2, ///< KDevelop 3 like, always shows the text and icons
-        STYLELAST = 0xffff
+        STYLELAST = 0xffff,
     };
     Q_ENUM(KMultiTabBarStyle)
 
@@ -63,7 +60,7 @@ public:
     explicit KMultiTabBar(QWidget *parent = nullptr);
 
     explicit KMultiTabBar(KMultiTabBarPosition pos, QWidget *parent = nullptr);
-    virtual ~KMultiTabBar();
+    ~KMultiTabBar() override;
 
     /**
      * append  a new button to the button area. The button can later on be accessed with button(ID)
@@ -83,7 +80,7 @@ public:
      * eg for connecting signals to it
      *
      * @param pic a pixmap for the button
-     * @param id an arbitraty ID value. It will be emitted in the clicked signal for identifying the button
+     * @param id an arbitrary ID value. It will be emitted in the clicked signal for identifying the button
      *  if more than one button is connected to a signals.
      * @param popup A popup menu which should be displayed if the button is clicked
      * @param not_used_yet will be used for a popup text in the future
@@ -173,8 +170,9 @@ protected:
     friend class KMultiTabBarButton;
     virtual void fontChange(const QFont &);
     void updateSeparator();
+
 private:
-    KMultiTabBarPrivate *const d;
+    std::unique_ptr<class KMultiTabBarPrivate> const d;
 };
 
 /**
@@ -182,7 +180,7 @@ private:
  *
  * Use KMultiTabBar::appendButton to append a button, which creates a KMultiTabBarButton instance
  */
-class KWIDGETSADDONS_EXPORT KMultiTabBarButton: public QPushButton
+class KWIDGETSADDONS_EXPORT KMultiTabBarButton : public QPushButton
 {
     Q_OBJECT
 public:
@@ -222,7 +220,7 @@ private:
     friend class KMultiTabBar;
 
     int m_id;
-    KMultiTabBarButtonPrivate *const d;
+    std::unique_ptr<class KMultiTabBarButtonPrivate> const d;
 };
 
 /**
@@ -230,7 +228,7 @@ private:
  *
  * Use KMultiTabBar::appendTab to append a tab, which creates a KMultiTabBarTab instance
  */
-class KWIDGETSADDONS_EXPORT KMultiTabBarTab: public KMultiTabBarButton
+class KWIDGETSADDONS_EXPORT KMultiTabBarTab : public KMultiTabBarButton
 {
     Q_OBJECT
 public:
@@ -270,16 +268,17 @@ public:
 
 protected:
     void paintEvent(QPaintEvent *) override;
+
 private:
     KMultiTabBar::KMultiTabBarPosition m_position;
     KMultiTabBar::KMultiTabBarStyle m_style;
 
-    void  computeMargins(int *hMargin, int *vMargin) const;
+    void computeMargins(int *hMargin, int *vMargin) const;
     QSize computeSizeHint(bool withText) const;
     bool shouldDrawText() const;
-    bool isVertical()     const;
+    bool isVertical() const;
 #if KWIDGETSADDONS_ENABLE_DEPRECATED_SINCE(5, 72)
-    QPixmap iconPixmap()  const;
+    QPixmap iconPixmap() const;
 #endif
 
     void initStyleOption(QStyleOptionToolButton *opt) const;
@@ -288,17 +287,20 @@ private:
     /**
      * This class should never be created except with the appendTab call of KMultiTabBar
      */
-    KMultiTabBarTab(const QIcon &icon, const QString &, int id, QWidget *parent,
-                    KMultiTabBar::KMultiTabBarPosition pos, KMultiTabBar::KMultiTabBarStyle style);
+    KMultiTabBarTab(const QIcon &icon, const QString &, int id, QWidget *parent, KMultiTabBar::KMultiTabBarPosition pos, KMultiTabBar::KMultiTabBarStyle style);
 #if KWIDGETSADDONS_ENABLE_DEPRECATED_SINCE(5, 72)
     /**
      * This class should never be created except with the appendTab call of KMultiTabBar
      */
     KWIDGETSADDONS_DEPRECATED_VERSION(5, 72, "Use overload with QIcon")
-    KMultiTabBarTab(const QPixmap &pic, const QString &, int id, QWidget *parent,
-                    KMultiTabBar::KMultiTabBarPosition pos, KMultiTabBar::KMultiTabBarStyle style);
+    KMultiTabBarTab(const QPixmap &pic,
+                    const QString &,
+                    int id,
+                    QWidget *parent,
+                    KMultiTabBar::KMultiTabBarPosition pos,
+                    KMultiTabBar::KMultiTabBarStyle style);
 #endif
-    KMultiTabBarTabPrivate *const d;
+    std::unique_ptr<class KMultiTabBarTabPrivate> const d;
 };
 
 #endif
