@@ -1,43 +1,26 @@
 /*
-  Copyright (c) 2014 Montel Laurent <montel@kde.org>
-  based on code:
-  Copyright 2009 Aurélien Gâteau <agateau@kde.org>
-  Copyright 2009 Kåre Sårs <kare.sars@iki.fi>
+    SPDX-FileCopyrightText: 2014 Montel Laurent <montel@kde.org>
+    based on code:
+    SPDX-FileCopyrightText: 2009 Aurélien Gâteau <agateau@kde.org>
+    SPDX-FileCopyrightText: 2009 Kåre Sårs <kare.sars@iki.fi>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Lesser General Public
-  License as published by the Free Software Foundation; either
-  version 2.1 of the License, or (at your option) version 3, or any
-  later version accepted by the membership of KDE e.V. (or its
-  successor approved by the membership of KDE e.V.), which shall
-  act as a proxy defined in Section 6 of version 3 of the license.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Lesser General Public License for more details.
-
-  You should have received a copy of the GNU Lesser General Public
-  License along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "ksplittercollapserbutton.h"
 
 // Qt
-#include <QApplication>
 #include <QEvent>
-#include <QMouseEvent>
 #include <QSplitter>
 #include <QStyleOptionToolButton>
 #include <QStylePainter>
 #include <QTimeLine>
-#include <QDebug>
 
 enum Direction {
     LeftToRight = 0,
     RightToLeft,
     TopToBottom,
-    BottomToTop
+    BottomToTop,
 };
 
 const static int TIMELINE_DURATION = 500;
@@ -47,17 +30,12 @@ const static qreal MINIMUM_OPACITY = 0.3;
 static const struct {
     Qt::ArrowType arrowVisible;
     Qt::ArrowType notArrowVisible;
-} s_arrowDirection[] = {
-    {Qt::LeftArrow,  Qt::RightArrow},
-    {Qt::RightArrow, Qt::LeftArrow},
-    {Qt::UpArrow, Qt::DownArrow},
-    {Qt::DownArrow,  Qt::UpArrow}
-};
+} s_arrowDirection[] = {{Qt::LeftArrow, Qt::RightArrow}, {Qt::RightArrow, Qt::LeftArrow}, {Qt::UpArrow, Qt::DownArrow}, {Qt::DownArrow, Qt::UpArrow}};
 
-class Q_DECL_HIDDEN KSplitterCollapserButton::Private
+class KSplitterCollapserButtonPrivate
 {
 public:
-    Private(KSplitterCollapserButton *qq);
+    KSplitterCollapserButtonPrivate(KSplitterCollapserButton *qq);
 
     KSplitterCollapserButton *q;
     QSplitter *splitter;
@@ -81,21 +59,20 @@ public:
     void startTimeLine();
 };
 
-KSplitterCollapserButton::Private::Private(KSplitterCollapserButton *qq)
-    : q(qq),
-      splitter(nullptr),
-      childWidget(nullptr),
-      opacityTimeLine(nullptr)
+KSplitterCollapserButtonPrivate::KSplitterCollapserButtonPrivate(KSplitterCollapserButton *qq)
+    : q(qq)
+    , splitter(nullptr)
+    , childWidget(nullptr)
+    , opacityTimeLine(nullptr)
 {
-
 }
 
-bool KSplitterCollapserButton::Private::isVertical() const
+bool KSplitterCollapserButtonPrivate::isVertical() const
 {
     return (splitter->orientation() == Qt::Vertical);
 }
 
-bool KSplitterCollapserButton::Private::isWidgetCollapsed() const
+bool KSplitterCollapserButtonPrivate::isWidgetCollapsed() const
 {
     const QRect widgetRect = childWidget->geometry();
     if ((widgetRect.height() == 0) || (widgetRect.width() == 0)) {
@@ -105,7 +82,7 @@ bool KSplitterCollapserButton::Private::isWidgetCollapsed() const
     }
 }
 
-void KSplitterCollapserButton::Private::updatePosition()
+void KSplitterCollapserButtonPrivate::updatePosition()
 {
     int x = 0;
     int y = 0;
@@ -114,7 +91,7 @@ void KSplitterCollapserButton::Private::updatePosition()
 
     if (!isVertical()) {
         const int splitterWidth = splitter->width();
-        const int width =  q->sizeHint().width();
+        const int width = q->sizeHint().width();
         // FIXME: Make this configurable
         y = 30;
         if (direction == LeftToRight) {
@@ -151,12 +128,12 @@ void KSplitterCollapserButton::Private::updatePosition()
     q->move(x, y);
 }
 
-void KSplitterCollapserButton::Private::updateArrow()
+void KSplitterCollapserButtonPrivate::updateArrow()
 {
-    q->setArrowType(isWidgetCollapsed() ?  s_arrowDirection[direction].notArrowVisible : s_arrowDirection[direction].arrowVisible);
+    q->setArrowType(isWidgetCollapsed() ? s_arrowDirection[direction].notArrowVisible : s_arrowDirection[direction].arrowVisible);
 }
 
-void KSplitterCollapserButton::Private::widgetEventFilter(QEvent *event)
+void KSplitterCollapserButtonPrivate::widgetEventFilter(QEvent *event)
 {
     switch (event->type()) {
     case QEvent::Resize:
@@ -173,7 +150,7 @@ void KSplitterCollapserButton::Private::widgetEventFilter(QEvent *event)
     }
 }
 
-void KSplitterCollapserButton::Private::updateOpacity()
+void KSplitterCollapserButtonPrivate::updateOpacity()
 {
     const QPoint pos = q->parentWidget()->mapFromGlobal(QCursor::pos());
     const QRect opaqueRect = q->geometry();
@@ -187,7 +164,7 @@ void KSplitterCollapserButton::Private::updateOpacity()
     }
 }
 
-void KSplitterCollapserButton::Private::startTimeLine()
+void KSplitterCollapserButtonPrivate::startTimeLine()
 {
     if (opacityTimeLine->state() == QTimeLine::Running) {
         opacityTimeLine->stop();
@@ -196,8 +173,8 @@ void KSplitterCollapserButton::Private::startTimeLine()
 }
 
 KSplitterCollapserButton::KSplitterCollapserButton(QWidget *childWidget, QSplitter *splitter)
-    : QToolButton(),
-      d(new Private(this))
+    : QToolButton()
+    , d(new KSplitterCollapserButtonPrivate(this))
 {
     setObjectName(QStringLiteral("splittercollapser"));
     // We do not want our collapser to be added as a regular widget in the
@@ -206,8 +183,7 @@ KSplitterCollapserButton::KSplitterCollapserButton(QWidget *childWidget, QSplitt
 
     d->opacityTimeLine = new QTimeLine(TIMELINE_DURATION, this);
     d->opacityTimeLine->setFrameRange(int(MINIMUM_OPACITY * 1000), 1000);
-    connect(d->opacityTimeLine, &QTimeLine::valueChanged,
-            this, QOverload<>::of(&QWidget::update));
+    connect(d->opacityTimeLine, &QTimeLine::valueChanged, this, qOverload<>(&QWidget::update));
 
     d->childWidget = childWidget;
     d->childWidget->installEventFilter(this);
@@ -235,10 +211,7 @@ KSplitterCollapserButton::KSplitterCollapserButton(QWidget *childWidget, QSplitt
     connect(this, &KSplitterCollapserButton::clicked, this, &KSplitterCollapserButton::slotClicked);
 }
 
-KSplitterCollapserButton::~KSplitterCollapserButton()
-{
-    delete d;
-}
+KSplitterCollapserButton::~KSplitterCollapserButton() = default;
 
 bool KSplitterCollapserButton::isWidgetCollapsed() const
 {
@@ -253,7 +226,11 @@ bool KSplitterCollapserButton::eventFilter(QObject *object, QEvent *event)
     return QToolButton::eventFilter(object, event);
 }
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+void KSplitterCollapserButton::enterEvent(QEnterEvent *event)
+#else
 void KSplitterCollapserButton::enterEvent(QEvent *event)
+#endif
 {
     Q_UNUSED(event)
     d->updateOpacity();
@@ -280,7 +257,7 @@ QSize KSplitterCollapserButton::sizeHint() const
     if (d->isVertical()) {
         sh.transpose();
     }
-    return sh.expandedTo(QApplication::globalStrut());
+    return sh;
 }
 
 void KSplitterCollapserButton::slotClicked()
@@ -358,4 +335,3 @@ void KSplitterCollapserButton::paintEvent(QPaintEvent *)
     initStyleOption(&opt2);
     painter.drawControl(QStyle::CE_ToolButtonLabel, opt2);
 }
-
